@@ -1,6 +1,7 @@
 import os
 import time
 import threading
+from flask import request, session
 from .redis_connect import RedisConnect
 from itsdangerous import TimedJSONWebSignatureSerializer as Serializer
 from .tools import handle_abnormal
@@ -14,6 +15,21 @@ logging.basicConfig(
 )
 
 
+def set_token_session(app, verify, per_defaults: list):
+    app.secret_key = 'sdfj48@$NF94@4dfsdf&)$#*'  # 配置session key
+
+    @app.before_request
+    def base_auth():
+        """验证用户是否有访问页面的权限"""
+        user = verify.verify_token(request)
+        session['token_id'] = user['token_id']
+        session['user_name'] = user['user_name']
+        session['real_name'] = user['real_name']
+        for per in per_defaults:
+            session[per['session_key']] = verify.permission_verify(
+                per['center_name'], per['permission_name'])
+
+
 class VerifyToken:
     def __init__(self, per_defaults=[{}], debug: bool = False):
         self.debug = debug  # 是否开启DEBUG模式
@@ -117,7 +133,8 @@ class VerifyToken:
                             if not self.permission_set_db.does_it_exist(find_dict):
                                 find_dict.update(
                                     {'permission_id': purview_name_id})
-                                self.permission_set_db.write_one_docu(docu=find_dict)
+                                self.permission_set_db.write_one_docu(
+                                    docu=find_dict)
                     else:
                         logging.error('计算组件未建立连接/依赖到认证中心，无法注册对应的角色')
             except Exception as e:
